##  MAIN_TAR_UR.R
##
##  This R program estimates a TAR(p+1).
##  It tests for a threshold and for unit roots.
##  
##  written by:
##  
##  Bruce E. Hansen
##  Department of Economics
##  Social Science Building
##  University of Wisconsin
##  Madison, WI 53706-1393
##  behansen@wisc.edu
##  http://www.ssc.wisc.edu/~bhansen/
##  
##  
##  This program reproduces the empirical application reported in
##  "Threshold Autoregression with a Near Unit Root"
##  by Mehmet Caner and Bruce E. Hansen.
##  To run this program as it is set, you need the data files
##  lhmu.dat and lhmc.dat
##  
##  It should work with other data sets as well.
##  
##  The program calls the procedure file TAR_UR.R.
##  
###########################################################################

source("tar_ur.R")

lhmu <- read.table("lhmu.dat")
lhmu <- as.matrix(lhmu)
y1 <- lhmu[1]-.01+1/12
lhmu <- lhmu[3:nrow(lhmu)]
lhmc <- read.table("lhmc.dat")
lhmc <- as.matrix(lhmc)
lhmc <- lhmc[3:nrow(lhmc)]
dat <- as.matrix((lhmu/lhmc)*100)
fst <- 97
dat <- as.matrix(dat[fst:nrow(dat)])
y1 <- y1 + (fst-1)/12
thresh <- 1
trim <- 1
trend <- 0
test <- seq(3,12,1)
p <- 12
mmin <- 1
mmax <- 12
m <- 9 

## No transformation ##
boot <- 10000                 
adj <- 0 
graph <- 1
yy <- dat
xdate <- as.matrix(seq(y1+(p+1)/12,y1+(p+1)/12+(nrow(dat)-p-2)/12,1/12))
        # These are the x-axis values for the graph  #
        # set _xdate="" if undated x-axis is okay    #
cat ("U.S. Adult Male Unemployment Rate", "\n")
out <- tar_ur(yy,p,mmin,mmax,m)

## First Half Sample ##
adj <- 0 
yy <- as.matrix(dat[1:floor(nrow(dat)/2)])
cat ("Unemployment Rate, First Sample","\n")
out <- tar_ur(yy,p,mmin,mmax,m)

## Second Half Sample ##
adj <- 0 
yy <- as.matrix(dat[(floor(nrow(dat)/2)+1):nrow(dat)])
date1 <- y1+floor(nrow(dat)/2)/12
cat ("Unemployment Rate, Second Sample","\n")
out <- tar_ur(yy,p,mmin,mmax,m)
date1 <- y1

## logit transformation x=log(u/(100-u)) ##
ldat <- log(dat/(100-dat))
adj <- sum(log((100/dat)/(100-dat)))
yy <- ldat
cat ("Logistic Unemployment Rate","\n")
out <- tar_ur(yy,p,mmin,mmax,m)

## log transformation   x=log(u) ##
ldat <- log(dat)
adj <- sum(-log(dat))
yy <- ldat
cat ("Log Unemployment Rate","\n")
out <- tar_ur(yy,p,mmin,mmax,m)

## log-type transformation x=-100*log(1-u/100) ##
ldat <- -log(1-dat/100)*100
adj <- sum(-log(1-dat/100))
yy <- ldat
cat ("Log-Type Unemployment Rate","\n")
out <- tar_ur(yy,p,mmin,mmax,m)

## exp transformation   x=exp(u/100) ##
ldat <- (exp(dat/100)-1)*100
adj <- sum(dat/100);
yy <- ldat
cat ("Exp Unemployment Rate","\n")
out <- tar_ur(yy,p,mmin,mmax,m)

## Alternative Trimming ##
trim <- 2
adj <- 0 
yy <- dat
cat ("U.S. Adult Male Unemployment Rate","\n")
out <- tar_ur(yy,p,mmin,mmax,m)

trim <- 3
cat ("U.S. Adult Male Unemployment Rate","\n")
out <- tar_ur(yy,p,mmin,mmax,m)

## Include Linear Trend ##
trim <- 1
trend <- 1 
cat ("U.S. Adult Male Unemployment Rate","\n")
out <- tar_ur(yy,p,mmin,mmax,m)

